"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));

// src/cli.ts
var import_commander = require("commander");

// src/main.ts
var import_path = __toESM(require("path"));
var glob = __toESM(require("glob"));
var import_fs = __toESM(require("fs"));

// src/util.ts
var regCustomProperty = /\s*-{2}[a-zA-F0-9-]+\s*:\s*[a-zA-Z0-9#\"\-\,\s\(\).]+\s*;\n*/g;
var getFinalOptions = (options2) => {
  return {
    include: options2.include || "**/*.?(css|scss|sass|less)",
    exclude: options2.exclude,
    output: options2.output || "./properties.ts"
  };
};

// src/main.ts
var loadedSassPreprocessor;
var main = async (options2) => {
  const finalOptions = getFinalOptions(options2);
  const filePaths = glob.sync(finalOptions.include, {
    ignore: finalOptions.exclude
  });
  let customProperties = /* @__PURE__ */ new Map();
  for (const filePath of filePaths) {
    try {
      const buffer = import_fs.default.readFileSync(filePath);
      const fileContent = buffer.toString();
      let customPropertyWithValues = null;
      if (filePath.endsWith(".scss") || filePath.endsWith(".sass")) {
        const sass = loadSassPreprocessor();
        const result = sass.renderSync({
          file: filePath,
          includePaths: ["node_modules"]
        });
        customPropertyWithValues = result.css.toString().match(regCustomProperty);
      } else if (filePath.endsWith(".less")) {
        const less = loadLessPreprocessor();
        const result = await less.render(fileContent, {
          paths: [import_path.default.dirname(filePath)]
        });
        customPropertyWithValues = result.css.match(regCustomProperty);
      } else {
        customPropertyWithValues = fileContent.match(regCustomProperty);
      }
      if (customPropertyWithValues) {
        customPropertyWithValues.map((customPropertyWithValue) => {
          const [customPropertyWithWhitespace, customPropertyValue] = customPropertyWithValue.split(":");
          const customProperty = customPropertyWithWhitespace.replaceAll(
            /[\s\n]*/g,
            ""
          );
          if (!customProperties.has(customProperty)) {
            customProperties.set(customProperty, customPropertyValue);
          }
        });
      }
    } catch (e) {
      console.log("e :>> ", e);
    }
  }
  const toCamelCase = (target) => target.replace(/^[A-Z]/, (m) => m.toLowerCase()).replace(/[-_ ./~ ]+([A-z0-9])/g, (m, $1) => $1.toUpperCase());
  let outputString = "";
  for (const customProperty of customProperties) {
    outputString = `${outputString}/**
`;
    outputString = `${outputString} * ${customProperty[1].replaceAll(
      /[\n]*/g,
      ""
    )}
`;
    outputString = `${outputString} */
`;
    outputString = `${outputString}export const ${toCamelCase(
      customProperty[0]
    )} = "var(${customProperty[0]})"
`;
  }
  import_fs.default.writeFileSync(import_path.default.resolve(finalOptions.output), outputString, {});
};
var loadSassPreprocessor = () => {
  try {
    if (loadedSassPreprocessor) {
      return loadedSassPreprocessor;
    }
    const fallbackPaths = require.resolve.paths?.("sass") || [];
    const resolved = require.resolve("sass", {
      paths: [__dirname, ...fallbackPaths]
    });
    return loadedSassPreprocessor = require(resolved);
  } catch (e) {
    console.error(e);
    throw new Error(
      `Preprocessor dependency 'sass' not found. Did you install it?`
    );
  }
};
var loadLessPreprocessor = () => {
  try {
    if (loadedSassPreprocessor) {
      return loadedSassPreprocessor;
    }
    const fallbackPaths = require.resolve.paths?.("less") || [];
    const resolved = require.resolve("less", {
      paths: [__dirname, ...fallbackPaths]
    });
    return loadedSassPreprocessor = require(resolved);
  } catch (e) {
    console.error(e);
    throw new Error(
      `Preprocessor dependency 'less' not found. Did you install it?`
    );
  }
};

// src/cli.ts
import_commander.program.option("-o, --output <path>", "output path.").option("-i, --include <path>", "include path to glob.").option("-e, --exclude <path>", "exclude path to glob.").parse(process.argv);
console.log("program.args :>> ", import_commander.program.args);
console.log("program.opts() :>> ", import_commander.program.opts());
var options = import_commander.program.opts();
main(options);
