var __require = /* @__PURE__ */ ((x) => typeof require !== "undefined" ? require : typeof Proxy !== "undefined" ? new Proxy(x, {
  get: (a, b) => (typeof require !== "undefined" ? require : a)[b]
}) : x)(function(x) {
  if (typeof require !== "undefined")
    return require.apply(this, arguments);
  throw new Error('Dynamic require of "' + x + '" is not supported');
});

// src/cli.ts
import { program } from "commander";

// src/main.ts
import path from "path";
import * as glob from "glob";
import fs from "fs";

// src/util.ts
var regCustomProperty = /\s*-{2}[a-zA-F0-9-]+\s*:\s*[a-zA-Z0-9#\"\-\,\s\(\).]+\s*;\n*/g;
var getFinalOptions = (options2) => {
  return {
    include: options2.include || "**/*.?(css|scss|sass|less)",
    exclude: options2.exclude,
    output: options2.output || "./properties.ts"
  };
};

// src/main.ts
var loadedSassPreprocessor;
var main = async (options2) => {
  const finalOptions = getFinalOptions(options2);
  const filePaths = glob.sync(finalOptions.include, {
    ignore: finalOptions.exclude
  });
  let customProperties = /* @__PURE__ */ new Map();
  for (const filePath of filePaths) {
    try {
      const buffer = fs.readFileSync(filePath);
      const fileContent = buffer.toString();
      let customPropertyWithValues = null;
      if (filePath.endsWith(".scss") || filePath.endsWith(".sass")) {
        const sass = loadSassPreprocessor();
        const result = sass.renderSync({
          file: filePath,
          includePaths: ["node_modules"]
        });
        customPropertyWithValues = result.css.toString().match(regCustomProperty);
      } else if (filePath.endsWith(".less")) {
        const less = loadLessPreprocessor();
        const result = await less.render(fileContent, {
          paths: [path.dirname(filePath)]
        });
        customPropertyWithValues = result.css.match(regCustomProperty);
      } else {
        customPropertyWithValues = fileContent.match(regCustomProperty);
      }
      if (customPropertyWithValues) {
        customPropertyWithValues.map((customPropertyWithValue) => {
          const [customPropertyWithWhitespace, customPropertyValue] = customPropertyWithValue.split(":");
          const customProperty = customPropertyWithWhitespace.replaceAll(
            /[\s\n]*/g,
            ""
          );
          if (!customProperties.has(customProperty)) {
            customProperties.set(customProperty, customPropertyValue);
          }
        });
      }
    } catch (e) {
      console.log("e :>> ", e);
    }
  }
  const toCamelCase = (target) => target.replace(/^[A-Z]/, (m) => m.toLowerCase()).replace(/[-_ ./~ ]+([A-z0-9])/g, (m, $1) => $1.toUpperCase());
  let outputString = "";
  for (const customProperty of customProperties) {
    outputString = `${outputString}/**
`;
    outputString = `${outputString} * ${customProperty[1].replaceAll(
      /[\n]*/g,
      ""
    )}
`;
    outputString = `${outputString} */
`;
    outputString = `${outputString}export const ${toCamelCase(
      customProperty[0]
    )} = "var(${customProperty[0]})"
`;
  }
  fs.writeFileSync(path.resolve(finalOptions.output), outputString, {});
};
var loadSassPreprocessor = () => {
  try {
    if (loadedSassPreprocessor) {
      return loadedSassPreprocessor;
    }
    const fallbackPaths = __require.resolve.paths?.("sass") || [];
    const resolved = __require.resolve("sass", {
      paths: [__dirname, ...fallbackPaths]
    });
    return loadedSassPreprocessor = __require(resolved);
  } catch (e) {
    console.error(e);
    throw new Error(
      `Preprocessor dependency 'sass' not found. Did you install it?`
    );
  }
};
var loadLessPreprocessor = () => {
  try {
    if (loadedSassPreprocessor) {
      return loadedSassPreprocessor;
    }
    const fallbackPaths = __require.resolve.paths?.("less") || [];
    const resolved = __require.resolve("less", {
      paths: [__dirname, ...fallbackPaths]
    });
    return loadedSassPreprocessor = __require(resolved);
  } catch (e) {
    console.error(e);
    throw new Error(
      `Preprocessor dependency 'less' not found. Did you install it?`
    );
  }
};

// src/cli.ts
program.option("-o, --output <path>", "output path.").option("-i, --include <path>", "include path to glob.").option("-e, --exclude <path>", "exclude path to glob.").parse(process.argv);
console.log("program.args :>> ", program.args);
console.log("program.opts() :>> ", program.opts());
var options = program.opts();
main(options);
